@@ -1,6 +1,6 @@
-from File import *
+from FilesOp import File
 
 __author__ = """KingKaitoKid"""
 __email__ = 'djstrix@me.com'
-__version__ = '1.0.2'
+__version__ = '1.0.3'
 name = "FilesOp"
\ No newline at end of file
